@@ -1,5 +1,5 @@
 /* Zutils - Utilities dealing with compressed files
-   Copyright (C) 2009-2025 Antonio Diaz Diaz.
+   Copyright (C) 2009-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ int verbosity = 0;
 namespace {
 
 const char * const config_file_name = "zutils.conf";
-const char * const     program_year = "2025";
+const char * const     program_year = "2026";
 
 std::string compressor_names[num_formats] =
   { "bzip2", "gzip", "lzip", "xz", "zstd" };	// default compressor names
@@ -100,7 +100,7 @@ bool trailing_escape( const std::string & s )
    Escaped newlines are discarded.
    Return the empty string if at EOF.
 */
-const std::string & my_fgets( FILE * const f, int & linenum )
+const std::string & my_fgets( FILE * const f, unsigned & linenum )
   {
   static std::string s;
   bool strip = true;			// strip leading whitespace
@@ -152,7 +152,7 @@ bool parse_compressor_command( const std::string & s, int i,
 
 
 bool parse_rc_line( const std::string & line,
-                    const char * const filename, const int linenum )
+                    const char * const filename, const unsigned linenum )
   {
   const int len = line.size();
   int i = 0;
@@ -161,7 +161,7 @@ bool parse_rc_line( const std::string & line,
   while( i < len && line[i] != '=' && !std::isspace( line[i] ) ) ++i;
   if( l >= i )
     { if( verbosity >= 0 )
-        std::fprintf( stderr, "%s %d: missing format name.\n", filename, linenum );
+        std::fprintf( stderr, "%s %u: missing format name.\n", filename, linenum );
       return false; }
   const std::string name( line, l, i - l );
   int format_index = -1;
@@ -169,20 +169,20 @@ bool parse_rc_line( const std::string & line,
     if( name == format_names[j] ) { format_index = j; break; }
   if( format_index < 0 )
     { if( verbosity >= 0 )
-        std::fprintf( stderr, "%s %d: bad format name '%s'\n",
+        std::fprintf( stderr, "%s %u: bad format name '%s'\n",
                       filename, linenum, name.c_str() );
       return false; }
 
   while( i < len && std::isspace( line[i] ) ) ++i;	// strip spaces
   if( i <= 0 || i >= len || line[i] != '=' )
     { if( verbosity >= 0 )
-        std::fprintf( stderr, "%s %d: missing '='\n", filename, linenum );
+        std::fprintf( stderr, "%s %u: missing '='\n", filename, linenum );
       return false; }
   ++i;							// skip the '='
   if( !parse_compressor_command( line, i, format_index ) )
     {
     if( verbosity >= 0 )
-      std::fprintf( stderr, "%s %d: missing compressor name.\n", filename, linenum );
+      std::fprintf( stderr, "%s %u: missing compressor name.\n", filename, linenum );
     return false;
     }
   return true;
@@ -195,7 +195,7 @@ int process_rcfile( const std::string & name )
   FILE * const f = std::fopen( name.c_str(), "r" );
   if( !f ) return 1;
 
-  int linenum = 0;
+  unsigned linenum = 0;
   int retval = 0;
 
   while( true )
@@ -344,8 +344,8 @@ const std::vector< std::string > & get_compressor_args( const int format_index )
 
 void show_help_addr()
   {
-  std::printf( "\nReport bugs to zutils-bug@nongnu.org\n"
-               "Zutils home page: http://www.nongnu.org/zutils/zutils.html\n" );
+  std::fputs( "\nReport bugs to zutils-bug@nongnu.org\n"
+    "Zutils home page: http://www.nongnu.org/zutils/zutils.html\n", stdout );
   }
 
 
@@ -363,9 +363,9 @@ void show_version( const char * const command )
       compressor_command += " -V 2> /dev/null";
       show_using_version( compressor_command.c_str() );
       }
-  std::printf( "License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>\n"
-               "This is free software: you are free to change and redistribute it.\n"
-               "There is NO WARRANTY, to the extent permitted by law.\n" );
+  std::fputs( "License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>\n"
+              "This is free software: you are free to change and redistribute it.\n"
+              "There is NO WARRANTY, to the extent permitted by law.\n", stdout );
   }
 
 
