@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Zutils - Utilities dealing with compressed files
-# Copyright (C) 2009-2025 Antonio Diaz Diaz.
+# Copyright (C) 2009-2026 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute, and modify it.
@@ -172,8 +172,9 @@ done
 "${ZCMP}" -N -n 100B in in6 || test_failed $LINENO
 "${ZCMP}" -N -n 1k in in6 || test_failed $LINENO
 "${ZCMP}" -N -n 10kB in in6 || test_failed $LINENO
-"${ZCMP}" -N -n 01750 in in6 || test_failed $LINENO
-"${ZCMP}" -N -n 0x3E8 in in6 || test_failed $LINENO
+"${ZCMP}" -N -n 01_750 in in6 || test_failed $LINENO
+"${ZCMP}" -N -n 0x3_E8 in in6 || test_failed $LINENO
+"${ZCMP}" -N -n 10_000 in in6 || test_failed $LINENO
 "${ZCMP}" -N -s in.tar pin.tar4
 [ $? = 1 ] || test_failed $LINENO
 "${ZCMP}" -N -q -i 0B:11B in.tar pin.tar4
@@ -336,17 +337,17 @@ printf "GNU\n" > patfile || framework_failure
 "${ZGREP}" -N -f patfile in > /dev/null || test_failed $LINENO
 rm -f patfile || framework_failure
 "${ZGREP}" -N "nx_pattern" empty && test_failed $LINENO
-"${ZGREP}" -N pin.tar4 -e "GNU" > /dev/null || test_failed $LINENO
-"${ZGREP}" -N "GNU" < pin.tar4 > /dev/null || test_failed $LINENO
-"${ZGREP}" -N -r "GNU" . > /dev/null || test_failed $LINENO
-"${ZGREP}" -N -r "GNU" > /dev/null || test_failed $LINENO
-"${ZGREP}" -N -R "GNU" . > /dev/null || test_failed $LINENO
-"${ZGREP}" -N -R "GNU" > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -l pin.tar4 -e "GNU" > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -l "GNU" < pin.tar4 > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -l -r "GNU" . > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -l -r "GNU" > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -l -R "GNU" . > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -l -R "GNU" > /dev/null || test_failed $LINENO
 "${ZGREP}" -N "nx_pattern" -r . in > /dev/null && test_failed $LINENO
 "${ZGREP}" -N -e "GNU" in > /dev/null || test_failed $LINENO
 "${ZGREP}" -N "GNU" < in > /dev/null || test_failed $LINENO
 "${ZGREP}" -N -O lz "nx_pattern" - - < in.lz > /dev/null && test_failed $LINENO
-"${ZGREP}" -N -O un "LZIP" in.lz > /dev/null || test_failed $LINENO
+"${ZGREP}" -N -O un -l "LZIP" in.lz > /dev/null || test_failed $LINENO
 "${ZGREP}" -N -e "-free" --lz='lzip -q' < in.lz > /dev/null ||
 	test_failed $LINENO
 "${ZGREP}" -N -- "-free" -in- > /dev/null || test_failed $LINENO
@@ -670,7 +671,7 @@ rm -r tmp2 || framework_failure
 
 if ln -s '.' slink 2> /dev/null ; then
 	"${ZCAT}" -N -r slink > /dev/null || test_failed $LINENO
-	"${ZGREP}" -N -r "GNU" slink > /dev/null || test_failed $LINENO
+	"${ZGREP}" -N -r -l "GNU" slink > /dev/null || test_failed $LINENO
 	"${ZTEST}" -N -r slink || test_failed $LINENO
 	"${ZUPDATE}" -N -r -f slink || test_failed $LINENO
 else
