@@ -1,5 +1,5 @@
 /* Zcmp - decompress and compare two files byte by byte
-   Copyright (C) 2010-2025 Antonio Diaz Diaz.
+   Copyright (C) 2010-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -50,52 +50,100 @@ namespace {
 
 void show_help()
   {
-  std::printf( "zcmp compares two files and, if they differ, writes to standard output the\n"
-               "first byte and line number where they differ. Bytes and lines are numbered\n"
-               "starting with 1. A hyphen '-' used as a file argument means standard input.\n"
-               "If any file given is compressed, its decompressed content is used. Compressed\n"
-               "files are decompressed on the fly; no temporary files are created.\n"
-               "\nThe formats supported are bzip2, gzip, lzip, xz, and zstd.\n"
-               "\nUsage: zcmp [options] file1 [file2]\n"
-               "\nzcmp compares file1 to file2. The standard input is used only if file1 or\n"
-               "file2 refers to standard input. If file2 is omitted zcmp tries to compare\n"
-               "file1 with the corresponding uncompressed file (if file1 is compressed), and\n"
-               "then with the corresponding compressed files of the remaining formats until\n"
-               "one is found.\n"
-               "\nExit status is 0 if inputs are identical, 1 if different, 2 if trouble.\n"
-               "\nOptions:\n"
-               "  -h, --help                        display this help and exit\n"
-               "  -V, --version                     output version information and exit\n"
-               "  -b, --print-bytes                 print differing bytes\n"
-               "  -H, --hexadecimal                 print hexadecimal values instead of octal\n"
-               "  -i, --ignore-initial=<n>[:<n2>]   ignore differences in the first <n> bytes\n"
-               "  -l, --list                        list position, value of all differing bytes\n"
-               "  -M, --format=<list>               process only the formats in <list>\n"
-               "  -n, --bytes=<n>                   compare at most <n> bytes\n"
-               "  -N, --no-rcfile                   don't read runtime configuration file\n"
-               "  -O, --force-format=[<f1>][,<f2>]  force one or both input formats\n"
-               "  -q, --quiet, --silent             suppress diagnostics written to stderr\n"
-               "  -s, --script                      suppress messages about file differences\n"
-               "  -v, --verbose                     verbose mode (opposite of --quiet)\n"
-               "      --bz2=<command>               set compressor and options for bzip2 format\n"
-               "      --gz=<command>                set compressor and options for gzip format\n"
-               "      --lz=<command>                set compressor and options for lzip format\n"
-               "      --xz=<command>                set compressor and options for xz format\n"
-               "      --zst=<command>               set compressor and options for zstd format\n"
-               "\nValid formats for options '-M' and '-O' are 'bz2', 'gz', 'lz', 'xz', 'zst',\n"
-               "and 'un' for uncompressed.\n"
-               "\nByte counts given as arguments to options may be expressed in decimal,\n"
-               "hexadecimal, or octal (using the same syntax as integer constants in C++),\n"
-               "and may be followed by a multiplier: k = kB = 10^3 = 1000,\n"
-               "Ki = KiB = 2^10 = 1024, M = 10^6, Mi = 2^20, G = 10^9, Gi = 2^30, etc.\n" );
+  std::fputs(
+    "zcmp compares two files and, if they differ, writes to standard output the\n"
+    "first byte and line number where they differ. Bytes and lines are numbered\n"
+    "starting with 1. A hyphen '-' used as a file argument means standard input.\n"
+    "If any file given is compressed, its decompressed content is used. Compressed\n"
+    "files are decompressed on the fly; no temporary files are created.\n"
+    "\nThe formats supported are bzip2, gzip, lzip, xz, and zstd.\n"
+    "\nUsage: zcmp [options] file1 [file2]\n"
+    "\nzcmp compares file1 to file2. The standard input is used only if file1 or\n"
+    "file2 refers to standard input. If file2 is omitted zcmp tries to compare\n"
+    "file1 with the corresponding uncompressed file (if file1 is compressed), and\n"
+    "then with the corresponding compressed files of the remaining formats until\n"
+    "one is found.\n"
+    "\nOptions:\n"
+    "  -h, --help                        display this help and exit\n"
+    "  -V, --version                     output version information and exit\n"
+    "  -b, --print-bytes                 print differing bytes\n"
+    "  -H, --hexadecimal                 print hexadecimal values instead of octal\n"
+    "  -i, --ignore-initial=<n>[:<n2>]   ignore differences in the first <n> bytes\n"
+    "  -l, --list                        list position, value of all differing bytes\n"
+    "  -M, --format=<list>               process only the formats in <list>\n"
+    "  -n, --bytes=<n>                   compare at most <n> bytes\n"
+    "  -N, --no-rcfile                   don't read runtime configuration file\n"
+    "  -O, --force-format=[<f1>][,<f2>]  force one or both input formats\n"
+    "  -q, --quiet, --silent             suppress diagnostics written to stderr\n"
+    "  -s, --script                      suppress messages about file differences\n"
+    "  -v, --verbose                     verbose mode (opposite of --quiet)\n"
+    "      --bz2=<command>               set compressor and options for bzip2 format\n"
+    "      --gz=<command>                set compressor and options for gzip format\n"
+    "      --lz=<command>                set compressor and options for lzip format\n"
+    "      --xz=<command>                set compressor and options for xz format\n"
+    "      --zst=<command>               set compressor and options for zstd format\n"
+    "\nValid formats for options '-M' and '-O' are 'bz2', 'gz', 'lz', 'xz', 'zst',\n"
+    "and 'un' for uncompressed.\n"
+    "\nByte counts given as arguments to options may be expressed in decimal,\n"
+    "hexadecimal, or octal (using the same syntax as integer constants in C++),\n"
+    "may contain underscore separators between groups of digits and\n"
+    "may be followed by a SI or binary multiplier: 1_234_567kB, 4KiB.\n"
+    "\n*Exit status*\n"
+    "0 if inputs are identical, 1 if different, 2 if trouble.\n", stdout );
   show_help_addr();
   }
 
 
+int chvalue( const unsigned char ch )
+  {
+  if( ch >= '0' && ch <= '9' ) return ch - '0';
+  if( ch >= 'A' && ch <= 'Z' ) return ch - 'A' + 10;
+  if( ch >= 'a' && ch <= 'z' ) return ch - 'a' + 10;
+  return 255;
+  }
+
+long long strtoll_( const char * const ptr, const char ** tail, int base )
+  {
+  if( tail ) *tail = ptr;				// error value
+  int i = 0;
+  while( std::isspace( ptr[i] ) || (unsigned char)ptr[i] == 0xA0 ) ++i;
+  const bool minus = ptr[i] == '-';
+  if( minus || ptr[i] == '+' ) ++i;
+  if( base < 0 || base > 36 || base == 1 ||
+      ( base == 0 && !std::isdigit( ptr[i] ) ) ||
+      ( base != 0 && chvalue( ptr[i] ) >= base ) )
+    { errno = EINVAL; return 0; }
+
+  if( base == 0 )
+    {
+    if( ptr[i] != '0' ) base = 10;			// decimal
+    else if( ptr[i+1] == 'x' || ptr[i+1] == 'X' ) { base = 16; i += 2; }
+    else base = 8;					// octal or 0
+    }
+  const int dpg = ( base != 16 ) ? 3 : 2;	// min digits per group
+  int dig = dpg - 1;	// digits in current group, first may have 1 digit
+  const unsigned long long limit = minus ? LLONG_MAX + 1ULL : LLONG_MAX;
+  unsigned long long result = 0;
+  bool erange = false;
+  for( ; ptr[i]; ++i )
+    {
+    if( ptr[i] == '_' ) { if( dig < dpg ) break; else { dig = 0; continue; } }
+    const int val = chvalue( ptr[i] ); if( val >= base ) break; else ++dig;
+    if( !erange && ( limit - val ) / base >= result )
+      result = result * base + val;
+    else erange = true;
+    }
+  if( dig < dpg ) { errno = EINVAL; return 0; }
+  if( tail ) *tail = ptr + i;
+  if( erange ) { errno = ERANGE; return minus ? LLONG_MIN : LLONG_MAX; }
+  return minus ? 0LL - result : result;
+  }
+
+
 // separate numbers of 5 or more digits in groups of 3 digits using '_'
 const char * format_num3p( long long num )
   {
-  enum { buffers = 8, bufsize = 4 * sizeof num, n = 10 };
+  enum { buffers = 8, bufsize = 4 * sizeof num };
   const char * const si_prefix = "kMGTPEZYRQ";
   const char * const binary_prefix = "KMGTPEZYRQ";
   static char buffer[buffers][bufsize];	// circle of buffers for printf
@@ -105,14 +153,14 @@ const char * format_num3p( long long num )
   char * p = buf + bufsize - 1;		// fill the buffer backwards
   *p = 0;				// terminator
   const bool negative = num < 0;
-  if( num > 9999 || num < -9999 )
+  if( num >= 10000 || num <= -10000 )
     {
     char prefix = 0;			// try binary first, then si
-    for( int i = 0; i < n && num != 0 && num % 1024 == 0; ++i )
+    for( int i = 0; num != 0 && num % 1024 == 0 && binary_prefix[i]; ++i )
       { num /= 1024; prefix = binary_prefix[i]; }
     if( prefix ) *(--p) = 'i';
     else
-      for( int i = 0; i < n && num != 0 && num % 1000 == 0; ++i )
+      for( int i = 0; num != 0 && num % 1000 == 0 && si_prefix[i]; ++i )
         { num /= 1000; prefix = si_prefix[i]; }
     if( prefix ) *(--p) = prefix;
     }
@@ -135,21 +183,21 @@ long long getnum( const char * const arg, const char * const option_name,
                   const long long llimit = 0,
                   const long long ulimit = LLONG_MAX )
   {
-  char * tail;
+  const char * tail;
   errno = 0;
-  long long result = strtoll( arg, &tail, 0 );
+  long long result = strtoll_( arg, &tail, 0 );
   if( tail == arg )
     { show_option_error( arg, "Bad or missing numerical argument in",
                          option_name ); std::exit( 2 ); }
   if( result < 0 ) errno = ERANGE;
 
-  if( !errno && tail[0] && std::isalpha( tail[0] ) )
+  if( !errno && *tail && std::isalpha( *tail ) )
     {
     const unsigned char ch = *tail++;
     int factor;
     bool bsuf;					// 'B' suffix is present
-    if( tail[0] == 'i' ) { ++tail; factor = 1024; } else factor = 1000;
-    if( tail[0] == 'B' ) { ++tail; bsuf = true; } else bsuf = false;
+    if( *tail == 'i' ) { ++tail; factor = 1024; } else factor = 1000;
+    if( *tail == 'B' ) { ++tail; bsuf = true; } else bsuf = false;
     int exponent = -1;				// -1 = bad multiplier
     switch( ch )
       {
