@@ -1,5 +1,5 @@
 /* Zupdate - recompress bzip2, gzip, xz, zstd files to lzip format
-   Copyright (C) 2013-2025 Antonio Diaz Diaz.
+   Copyright (C) 2013-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -56,53 +56,55 @@ namespace {
 
 void show_help()
   {
-  std::printf( "zupdate recompresses files from bzip2, gzip, xz, and zstd formats to lzip\n"
-               "format. Each original is compared with the new file and then deleted.\n"
-               "Only regular files with standard file name extensions are recompressed,\n"
-               "other files are ignored. Compressed files are decompressed and then\n"
-               "recompressed on the fly; no temporary files are created. The lzip format\n"
-               "is chosen as destination because it is the most appropriate for\n"
-               "long-term archiving.\n"
-               "\nIf no files are specified, recursive searches examine the current\n"
-               "working directory, and nonrecursive searches do nothing.\n"
-               "\nIf the lzip-compressed version of a file already exists, the file is skipped\n"
-               "unless the option '--force' is given. In this case, if the comparison with\n"
-               "the existing lzip version fails, an error is returned and the original file\n"
-               "is not deleted. The operation of zupdate is meant to be safe and not cause\n"
-               "any data loss. Therefore, existing lzip-compressed files are never\n"
-               "overwritten nor deleted.\n"
-               "\nThe names of the original files must have one of the following extensions:\n"
-               "\n'.bz2', '.gz', '.xz', '.zst', or '.Z', which are recompressed to '.lz'.\n"
-               "\n'.tbz', '.tbz2', '.tgz', '.txz', or '.tzst', which are recompressed to '.tlz'.\n"
-               "\nUsage: zupdate [options] [files]\n"
-               "\nExit status is 0 if all the compressed files were successfully recompressed\n"
-               "(if needed), compared, and deleted (if requested). 1 if a non-fatal error\n"
-               "occurred (file not found or not regular, or has invalid format, or can't be\n"
-               "deleted). 2 if a fatal error occurred (invalid command-line options,\n"
-               "compressor can't be run, or comparison fails).\n"
-               "\nOptions:\n"
-               "  -h, --help                   display this help and exit\n"
-               "  -V, --version                output version information and exit\n"
-               "  -d, --destdir=<dir>          write recompressed files into <dir>\n"
-               "  -e, --expand-extensions      expand combined extensions; tgz --> tar.lz\n"
-               "  -f, --force                  don't skip a file even if the .lz exists\n"
-               "  -i, --ignore-errors          ignore non-fatal errors\n"
-               "  -k, --keep                   keep (don't delete) input files\n"
-               "  -l, --lzip-verbose           pass one option -v to the lzip compressor\n"
-               "  -M, --format=<list>          process only the formats in <list>\n"
-               "  -N, --no-rcfile              don't read runtime configuration file\n"
-               "  -q, --quiet                  suppress all messages\n"
-               "  -r, --recursive              operate recursively on directories\n"
-               "  -R, --dereference-recursive  recursively follow symbolic links\n"
-               "  -v, --verbose                be verbose (a 2nd -v gives more)\n"
-               "  -x, --exclude=<pattern>      exclude files matching a shell pattern\n"
-               "  -0 .. -9                     set compression level [default 9]\n"
-               "      --bz2=<command>          set compressor and options for bzip2 format\n"
-               "      --gz=<command>           set compressor and options for gzip format\n"
-               "      --lz=<command>           set compressor and options for lzip format\n"
-               "      --xz=<command>           set compressor and options for xz format\n"
-               "      --zst=<command>          set compressor and options for zstd format\n"
-               "\nValid formats for option '-M' are 'bz2', 'gz', 'xz', and 'zst'.\n" );
+  std::fputs(
+    "zupdate recompresses files from bzip2, gzip, xz, and zstd formats to lzip\n"
+    "format. Each original is compared with the new file and then deleted.\n"
+    "Only regular files with standard file name extensions are recompressed,\n"
+    "other files are ignored. Compressed files are decompressed and then\n"
+    "recompressed on the fly; no temporary files are created. The lzip format\n"
+    "is chosen as destination because it is the most appropriate for\n"
+    "long-term archiving.\n"
+    "\nIf no files are specified, recursive searches examine the current\n"
+    "working directory, and nonrecursive searches do nothing.\n"
+    "\nIf the lzip-compressed version of a file already exists, the file is skipped\n"
+    "unless the option '--force' is given. In this case, if the comparison with\n"
+    "the existing lzip version fails, an error is returned and the original file\n"
+    "is not deleted. The operation of zupdate is meant to be safe and not cause\n"
+    "any data loss. Therefore, existing lzip-compressed files are never\n"
+    "overwritten nor deleted.\n"
+    "\nThe names of the original files must have one of the following extensions:\n"
+    "\n'.bz2', '.gz', '.xz', '.zst', or '.Z', which are recompressed to '.lz'.\n"
+    "\n'.tbz', '.tbz2', '.tgz', '.txz', or '.tzst', which are recompressed to '.tlz'.\n"
+    "\nUsage: zupdate [options] [files]\n"
+    "\nOptions:\n"
+    "  -h, --help                   display this help and exit\n"
+    "  -V, --version                output version information and exit\n"
+    "  -d, --destdir=<dir>          write recompressed files into <dir>\n"
+    "  -e, --expand-extensions      expand combined extensions; tgz --> tar.lz\n"
+    "  -f, --force                  don't skip a file even if the .lz exists\n"
+    "  -i, --ignore-errors          ignore non-fatal errors\n"
+    "  -k, --keep                   keep (don't delete) input files\n"
+    "  -l, --lzip-verbose           pass one option -v to the lzip compressor\n"
+    "  -M, --format=<list>          process only the formats in <list>\n"
+    "  -N, --no-rcfile              don't read runtime configuration file\n"
+    "  -q, --quiet                  suppress all messages\n"
+    "  -r, --recursive              operate recursively on directories\n"
+    "  -R, --dereference-recursive  recursively follow symbolic links\n"
+    "  -v, --verbose                be verbose (a 2nd -v gives more)\n"
+    "  -x, --exclude=<pattern>      exclude files matching a shell pattern\n"
+    "  -0 .. -9                     set compression level [default 9]\n"
+    "      --bz2=<command>          set compressor and options for bzip2 format\n"
+    "      --gz=<command>           set compressor and options for gzip format\n"
+    "      --lz=<command>           set compressor and options for lzip format\n"
+    "      --xz=<command>           set compressor and options for xz format\n"
+    "      --zst=<command>          set compressor and options for zstd format\n"
+    "\nValid formats for option '-M' are 'bz2', 'gz', 'xz', and 'zst'.\n"
+    "\n*Exit status*\n"
+    "0 if all the compressed files were successfully recompressed\n"
+    "(if needed), compared, and deleted (if requested). 1 if a non-fatal error\n"
+    "occurred (file not found or not regular, or has invalid format, or can't be\n"
+    "deleted). 2 if a fatal error occurred (invalid command-line options,\n"
+    "compressor can't be run, or comparison fails).\n", stdout );
   show_help_addr();
   }
 
